function [data]=sacsort(data,field,mode)
%SACSORT   Sort SAC data by a header field
%
%   Sorts SAC data according to a header
%   field.  Mode is optional (ascending
%   order is default) but may be 'descend'.
%
%   Usage:  [data]=sacsort(data,field,mode);
%
%   Example: 
%
%       sort by degree distance (in reverse)
%
%       [data]=sacsort(data,'gcarc','descend');
%
%    by Garrett Euler (10/2007)   ggeuler@wustl.edu
%
%    See also: lh, gh

% do nothing on no field
if(nargin<2)
    return
end

% check data structure
if(~isstruct(data))
    error('sac data is not a structure')
elseif(~isfield(data,'name') || ~isfield(data,'head'))
    error('sac data structure does not have proper fields')
end

% check args
error(nargchk(2,3,nargin))

% set mode if none
if(nargin<3)
    mode='ascend';
end

% get field values
values=gh(data,field);

% special handling of cell array of strings
if(isnumeric(values))
    [values,indices]=sort(values,mode);
else
    [values,indices]=sort(values);
    if(strcmpi(mode,'descend'))
        indices=indices(end:-1:1);
    end
end

% sort data
data=data(indices);
